@@ -15,6 +15,17 @@ class BaseAbstractModel(models.Model):
         pass
 
 
+class AnotherFromAbstractModel(BaseAbstractModel):
+    """
+    This class exists to trigger a regression when multiple concrete classes
+    inherit from a shared abstract class (example: BaseAbstractModel).
+    Don't try to remove it.
+    """
+    @transition(field="state", source="published", target="sticked")
+    def stick(self):
+        pass
+
+
 class InheritedFromAbstractModel(BaseAbstractModel):
     @transition(field="state", source="published", target="sticked")
     def stick(self):
