@@ -1,10 +1,7 @@
-from __future__ import annotations
-
 from django.db import models
 from django.test import TestCase
 
-from django_fsm import FSMField
-from django_fsm import transition
+from django_fsm import FSMField, transition
 
 
 class ProtectedAccessModel(models.Model):
