@@ -1,10 +1,6 @@
-from __future__ import annotations
-
 from django.db import models
 from django.test import TestCase
-
-from django_fsm import FSMField
-from django_fsm import transition
+from django_fsm import FSMField, transition
 
 
 class BlogPostWithCustomData(models.Model):
@@ -14,11 +10,11 @@ class BlogPostWithCustomData(models.Model):
     def publish(self):
         pass
 
-    @transition(field=state, source="published", target="destroyed", custom={"label": "Destroy", "type": "manual"})
+    @transition(field=state, source="published", target="destroyed", custom=dict(label="Destroy", type="manual"))
     def destroy(self):
         pass
 
-    @transition(field=state, source="published", target="review", custom={"label": "Periodic review", "type": "automated"})
+    @transition(field=state, source="published", target="review", custom=dict(label="Periodic review", type="automated"))
     def review(self):
         pass
 
