@@ -4,22 +4,22 @@ from django_fsm import FSMField, transition
 
 
 class BlogPostWithStringField(models.Model):
-    state = FSMField(default='new')
+    state = FSMField(default="new")
 
-    @transition(field='state', source='new', target='published', conditions=[])
+    @transition(field="state", source="new", target="published", conditions=[])
     def publish(self):
         pass
 
-    @transition(field='state', source='published', target='destroyed')
+    @transition(field="state", source="published", target="destroyed")
     def destroy(self):
         pass
 
-    @transition(field='state', source='published', target='review')
+    @transition(field="state", source="published", target="review")
     def review(self):
         pass
 
     class Meta:
-        app_label = 'testapp'
+        app_label = "testapp"
 
 
 class StringFieldTestCase(TestCase):
@@ -27,6 +27,6 @@ class StringFieldTestCase(TestCase):
         self.model = BlogPostWithStringField()
 
     def test_initial_state(self):
-        self.assertEqual(self.model.state, 'new')
+        self.assertEqual(self.model.state, "new")
         self.model.publish()
-        self.assertEqual(self.model.state, 'published')
+        self.assertEqual(self.model.state, "published")
